@@ -1,5 +1,6 @@
-import subprocess
+
 import click
+from check_breach_password.check_breach import main
 
 
 # tells click that the function will be a click command
@@ -21,12 +22,8 @@ def cli(passwords):
     if len(passwords) == 0:
         print("Please pass at least one argument. Run breach check --help for more information")
         return
-    password_string = ""
-    for password in passwords:
-        password_string += password + " "
 
-    command = f"python main.py {password_string}"
+    print("Password is being Checked. Please wait.\n")
+    main(list(passwords))
 
-    # subprocess.call runs the command line equivalent code from file
-    result = subprocess.call(command, shell=True)
 
